==> komga_api_client-0.41.1.tar.gz: doc/UserControllerApi.md <==
# komga_api_client.api.UserControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *http://localhost:8080*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addOne2**](UserControllerApi.md#addOne2) | **post** /api/v1/users | 
[**delete**](UserControllerApi.md#delete) | **delete** /api/v1/users/{id} | 
[**getAll2**](UserControllerApi.md#getAll2) | **get** /api/v1/users | 
[**getMe**](UserControllerApi.md#getMe) | **get** /api/v1/users/me | 
[**updatePassword**](UserControllerApi.md#updatePassword) | **patch** /api/v1/users/me/password | 
[**updateSharesLibraries**](UserControllerApi.md#updateSharesLibraries) | **patch** /api/v1/users/{id}/shared-libraries | 
[**updateUserRoles**](UserControllerApi.md#updateUserRoles) | **patch** /api/v1/users/{id} | 


# **addOne2**
> UserDto addOne2(userCreationDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var userCreationDto = new UserCreationDto(); // UserCreationDto | 

try { 
    var result = api_instance.addOne2(userCreationDto);
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->addOne2: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **userCreationDto** | [**UserCreationDto**](UserCreationDto.md)|  | 

### Return type

[**UserDto**](UserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete**
> delete(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 

try { 
    api_instance.delete(id);
} catch (e) {
    print("Exception when calling UserControllerApi->delete: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAll2**
> List<UserWithSharedLibrariesDto> getAll2()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();

try { 
    var result = api_instance.getAll2();
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->getAll2: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<UserWithSharedLibrariesDto>**](UserWithSharedLibrariesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMe**
> UserDto getMe()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();

try { 
    var result = api_instance.getMe();
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->getMe: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UserDto**](UserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePassword**
> updatePassword(passwordUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var passwordUpdateDto = new PasswordUpdateDto(); // PasswordUpdateDto | 

try { 
    api_instance.updatePassword(passwordUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updatePassword: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **passwordUpdateDto** | [**PasswordUpdateDto**](PasswordUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateSharesLibraries**
> updateSharesLibraries(id, sharedLibrariesUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 
var sharedLibrariesUpdateDto = new SharedLibrariesUpdateDto(); // SharedLibrariesUpdateDto | 

try { 
    api_instance.updateSharesLibraries(id, sharedLibrariesUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updateSharesLibraries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]
 **sharedLibrariesUpdateDto** | [**SharedLibrariesUpdateDto**](SharedLibrariesUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateUserRoles**
> updateUserRoles(id, rolesUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 
var rolesUpdateDto = new RolesUpdateDto(); // RolesUpdateDto | 

try { 
    api_instance.updateUserRoles(id, rolesUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updateUserRoles: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]
 **rolesUpdateDto** | [**RolesUpdateDto**](RolesUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> komga_api_client-37.0.0.tar.gz: doc/UserControllerApi.md <==
# komga_api_client.api.UserControllerApi

## Load the API package
```dart
import 'package:komga_api_client/api.dart';
```

All URIs are relative to *https://demo.komga.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addOne1**](UserControllerApi.md#addOne1) | **post** /api/v1/users | 
[**delete**](UserControllerApi.md#delete) | **delete** /api/v1/users/{id} | 
[**getAll1**](UserControllerApi.md#getAll1) | **get** /api/v1/users | 
[**getMe**](UserControllerApi.md#getMe) | **get** /api/v1/users/me | 
[**updatePassword**](UserControllerApi.md#updatePassword) | **patch** /api/v1/users/me/password | 
[**updateSharesLibraries**](UserControllerApi.md#updateSharesLibraries) | **patch** /api/v1/users/{id}/shared-libraries | 
[**updateUserRoles**](UserControllerApi.md#updateUserRoles) | **patch** /api/v1/users/{id} | 


# **addOne1**
> UserDto addOne1(userCreationDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var userCreationDto = new UserCreationDto(); // UserCreationDto | 

try { 
    var result = api_instance.addOne1(userCreationDto);
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->addOne1: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **userCreationDto** | [**UserCreationDto**](UserCreationDto.md)|  | 

### Return type

[**UserDto**](UserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete**
> delete(id)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 

try { 
    api_instance.delete(id);
} catch (e) {
    print("Exception when calling UserControllerApi->delete: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAll1**
> List<UserWithSharedLibrariesDto> getAll1()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();

try { 
    var result = api_instance.getAll1();
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->getAll1: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**List<UserWithSharedLibrariesDto>**](UserWithSharedLibrariesDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getMe**
> UserDto getMe()



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();

try { 
    var result = api_instance.getMe();
    print(result);
} catch (e) {
    print("Exception when calling UserControllerApi->getMe: $e\n");
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**UserDto**](UserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updatePassword**
> updatePassword(passwordUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var passwordUpdateDto = new PasswordUpdateDto(); // PasswordUpdateDto | 

try { 
    api_instance.updatePassword(passwordUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updatePassword: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **passwordUpdateDto** | [**PasswordUpdateDto**](PasswordUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateSharesLibraries**
> updateSharesLibraries(id, sharedLibrariesUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 
var sharedLibrariesUpdateDto = new SharedLibrariesUpdateDto(); // SharedLibrariesUpdateDto | 

try { 
    api_instance.updateSharesLibraries(id, sharedLibrariesUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updateSharesLibraries: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]
 **sharedLibrariesUpdateDto** | [**SharedLibrariesUpdateDto**](SharedLibrariesUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateUserRoles**
> updateUserRoles(id, rolesUpdateDto)



### Example 
```dart
import 'package:komga_api_client/api.dart';

var api_instance = new UserControllerApi();
var id = 789; // int | 
var rolesUpdateDto = new RolesUpdateDto(); // RolesUpdateDto | 

try { 
    api_instance.updateUserRoles(id, rolesUpdateDto);
} catch (e) {
    print("Exception when calling UserControllerApi->updateUserRoles: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **int**|  | [default to null]
 **rolesUpdateDto** | [**RolesUpdateDto**](RolesUpdateDto.md)|  | 

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
